==> xfxwidgets-1.8.43.tar.gz: lib/XF_SCHEDA/XfxScheda.dart <==
part of xfxwidgets;

class XfxScheda extends StatefulWidget {
  XfxScheda({
    Key? key,
    this.title = "",
    this.title_Visible = true,
    this.child,
    this.bottomBar_Visible = true,
    this.bottomBar_OnTap,
    this.bottomBar_CurrentIdx,
    required this.bottomBar_Children,
  }) : super(key: key);
  final String title;
  final Widget? child;
  final bool title_Visible;
  final Function(int)? bottomBar_OnTap;
  final bool? bottomBar_Visible;
  final int? bottomBar_CurrentIdx;

  List<BottomNavigationBarItem> bottomBar_Children;
  @override
  _XfxSchedaState createState() => _XfxSchedaState();
}

class _XfxSchedaState extends State<XfxScheda> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: XColors.backgroundDark,
        body: Container(
            margin: EdgeInsets.symmetric(horizontal: 15),
            child: Column(children: [
              SizedBox(height: 10),
              widget.title_Visible == true
                  ? Row(
                      children: [
                        Expanded(child: XContainerWithLabel(widget.title, height: 30, color: XColors.backGroundTitleContainerForScheda_MAIN, textStyle: XStyles.xStyTextForTextBase(XColors.foregroundDark))),
                      ],
                    )
                  : Container(),
              SizedBox(height: 3),
              SingleChildScrollView(
                child: Container(child: widget.child ?? Container()),
              ),
              SizedBox(height: 5),
            ])),
        bottomNavigationBar: widget.bottomBar_Visible == true
            ? BottomNavigationBar(
                type: BottomNavigationBarType.fixed,
                currentIndex: widget.bottomBar_CurrentIdx ?? 0,
                onTap: widget.bottomBar_OnTap,
                enableFeedback: true,
                showUnselectedLabels: true,
                selectedItemColor: Colors.blue[700],
                selectedFontSize: 15,
                selectedLabelStyle: XStyles.xStyleText(fontSize: 10),
                backgroundColor: Colors.grey[900],
                unselectedItemColor: XColors.foregroundLight,
                unselectedFontSize: 10,
                unselectedLabelStyle: XStyles.xStyleText(fontSize: 10),
                iconSize: 20,
                items: widget.bottomBar_Children,
              )
            : Container(height: 1));
  }
}

==> xfxwidgets-1.9.5.tar.gz: lib/XF_SCHEDA/XfxScheda.dart <==
part of xfxwidgets;

class XfxScheda extends StatefulWidget {
  XfxScheda({
    Key? key,
    this.title = "",
    this.title_Visible = true,
    this.child,
    this.bottomBar_Visible = true,
    this.bottomBar_OnTap,
    this.bottomBar_CurrentIdx,
    required this.bottomBar_Children,
  }) : super(key: key);
  final String title;
  final Widget? child;
  final bool title_Visible;
  final Function(int)? bottomBar_OnTap;
  final bool? bottomBar_Visible;
  final int? bottomBar_CurrentIdx;

  List<BottomNavigationBarItem> bottomBar_Children;
  @override
  _XfxSchedaState createState() => _XfxSchedaState();
}

class _XfxSchedaState extends State<XfxScheda> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: XColors.backgroundDark,
        body: Container(
            margin: EdgeInsets.symmetric(horizontal: 15),
            child: Column(children: [
              SizedBox(height: 10),
              widget.title_Visible == true
                  ? Row(
                      children: [
                        Expanded(child: XContainerWithLabel(widget.title, height: 30, color: XColors.backGroundTitleContainerForScheda_MAIN, textStyle: XStyles.xStyTextForTextBase(textColor: XColors.foregroundDark))),
                      ],
                    )
                  : Container(),
              SizedBox(height: 3),
              SingleChildScrollView(
                child: Container(child: widget.child ?? Container()),
              ),
              SizedBox(height: 5),
            ])),
        bottomNavigationBar: widget.bottomBar_Visible == true
            ? BottomNavigationBar(
                type: BottomNavigationBarType.fixed,
                currentIndex: widget.bottomBar_CurrentIdx ?? 0,
                onTap: widget.bottomBar_OnTap,
                enableFeedback: true,
                showUnselectedLabels: true,
                selectedItemColor: Colors.blue[700],
                selectedFontSize: 15,
                selectedLabelStyle: XStyles.xStyleText(fontSize: 10),
                backgroundColor: Colors.grey[900],
                unselectedItemColor: XColors.foregroundLight,
                unselectedFontSize: 10,
                unselectedLabelStyle: XStyles.xStyleText(fontSize: 10),
                iconSize: 20,
                items: widget.bottomBar_Children,
              )
            : Container(height: 1));
  }
}
